/*
 * IcmpDebug.h
 *
 * Copyright (c) Verax Systems.
 * All rights reserved.
 *
 * This software is furnished under a license. Use, duplication,
 * disclosure and all other uses are restricted to the rights
 * specified in the written license agreement.
 */
/**
 * @file IcmpDebug.h
 *
 * @brief ICMP API: printing debug messages.
 *
 * File contains function to print debug messages using Win32 system function OutputDebugString.
 * 
 */


#ifndef __ICMPDEBUG_H__
#define __ICMPDEBUG_H__

#include <windows.h>


/**
 * @brief Write message to Windows debug output.
 *
 * Function prints formatted message to Windows debug output. In case illegal
 * format is specified the message is not printed @see vsprintf specification. 
 *
 * @param format format of message to be printed (as in vsprintf)        
 * @param  ...  list of parameters to be printed
 */
#ifdef DEBUG
void IcmpOutputDebugString(const char *format, ...);
#else
void IcmpOutputDebugString()                       ;
#endif

#endif
